==> kubernetes-model-1.0.60-sources.jar: annotations/io/fabric8/kubernetes/api/model/PreferencesBuilder.java <==
package io.fabric8.kubernetes.api.model;

import javax.validation.Validation;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.util.Set;
import javax.annotation.Generated;
import javax.validation.ValidationException;
import javax.validation.ValidatorFactory;
import lombok.EqualsAndHashCode;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.databind.annotation.JsonDeserialize;
import javax.validation.ConstraintViolation;
import javax.validation.ConstraintViolationException;
import java.lang.Object;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import java.lang.Boolean;
import lombok.ToString;
import io.sundr.builder.annotations.Buildable;
import javax.validation.Validator;

public class PreferencesBuilder extends PreferencesFluentImpl<PreferencesBuilder> implements VisitableBuilder<Preferences,PreferencesBuilder>{

    PreferencesFluent<?> fluent;
    Boolean validationEnabled;

    public PreferencesBuilder(){
            this(true);
    }
    public PreferencesBuilder(Boolean validationEnabled){
            this(new Preferences(), validationEnabled);
    }
    public PreferencesBuilder(PreferencesFluent<?> fluent){
            this(fluent, true);
    }
    public PreferencesBuilder(PreferencesFluent<?> fluent,Boolean validationEnabled){
            this(fluent, new Preferences(), validationEnabled);
    }
    public PreferencesBuilder(PreferencesFluent<?> fluent,Preferences instance){
            this(fluent, instance, true);
    }
    public PreferencesBuilder(PreferencesFluent<?> fluent,Preferences instance,Boolean validationEnabled){
            this.fluent = fluent; 
            fluent.withColors(instance.getColors()); 
            fluent.withExtensions(instance.getExtensions()); 
            this.validationEnabled = validationEnabled; 
    }
    public PreferencesBuilder(Preferences instance){
            this(instance,true);
    }
    public PreferencesBuilder(Preferences instance,Boolean validationEnabled){
            this.fluent = this; 
            this.withColors(instance.getColors()); 
            this.withExtensions(instance.getExtensions()); 
            this.validationEnabled = validationEnabled; 
    }

    public Preferences build(){
            Preferences buildable = new Preferences(fluent.isColors(),fluent.getExtensions());
            validate(buildable);
            return buildable;
    }

    private <T>void validate(T item){
            if (!validationEnabled) { return; }
            Validator validator = null;
            try {
                ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
                validator = factory.getValidator();
            } catch(ValidationException e) {return;}
            Set<ConstraintViolation<T>> violations = validator.validate(item);
            if (!violations.isEmpty()) {
            throw new ConstraintViolationException(violations);
             }
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            PreferencesBuilder that = (PreferencesBuilder) o;
            if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

            if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
            return true;
    }




}

==> kubernetes-model-1.0.64-sources.jar: annotations/io/fabric8/kubernetes/api/model/PreferencesBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import javax.annotation.Generated;
import lombok.EqualsAndHashCode;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.databind.annotation.JsonDeserialize;
import java.lang.Object;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import java.lang.Boolean;
import lombok.ToString;
import io.sundr.builder.annotations.Buildable;

public class PreferencesBuilder extends PreferencesFluentImpl<PreferencesBuilder> implements VisitableBuilder<Preferences,PreferencesBuilder>{

    PreferencesFluent<?> fluent;
    Boolean validationEnabled;

    public PreferencesBuilder(){
            this(true);
    }
    public PreferencesBuilder(Boolean validationEnabled){
            this(new Preferences(), validationEnabled);
    }
    public PreferencesBuilder(PreferencesFluent<?> fluent){
            this(fluent, true);
    }
    public PreferencesBuilder(PreferencesFluent<?> fluent,Boolean validationEnabled){
            this(fluent, new Preferences(), validationEnabled);
    }
    public PreferencesBuilder(PreferencesFluent<?> fluent,Preferences instance){
            this(fluent, instance, true);
    }
    public PreferencesBuilder(PreferencesFluent<?> fluent,Preferences instance,Boolean validationEnabled){
            this.fluent = fluent; 
            fluent.withColors(instance.getColors()); 
            fluent.withExtensions(instance.getExtensions()); 
            this.validationEnabled = validationEnabled; 
    }
    public PreferencesBuilder(Preferences instance){
            this(instance,true);
    }
    public PreferencesBuilder(Preferences instance,Boolean validationEnabled){
            this.fluent = this; 
            this.withColors(instance.getColors()); 
            this.withExtensions(instance.getExtensions()); 
            this.validationEnabled = validationEnabled; 
    }

    public Preferences build(){
            Preferences buildable = new Preferences(fluent.isColors(),fluent.getExtensions());
            io.fabric8.kubernetes.api.builder.ValidationUtils.validate(buildable);
            return buildable;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            PreferencesBuilder that = (PreferencesBuilder) o;
            if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

            if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
            return true;
    }




}
